@@ -65,13 +65,13 @@ tsplot(stages, shading="series", boxes="series",xlim=c(100,81))
 ranges(fossils, tax="genus", bin="mid", labs=T, labels.args=list(cex=0.2))
 
 ## ----ranplot3, echo= TRUE, plot=TRUE, fig.height=5.5---------------------
-tsplot(stages, shading="stage", boxes=c("stage","series"),xlim=c(100,81))
+tsplot(stages, shading="stage", boxes=c("stage","series"),xlim=c(100,80))
 
 ranges(fossils, tax="genus", bin="mid", labs=T, 
   labels.args=list(cex=0.6), filt="orig", occs=T)
 
 ## ----ranplot4, echo= TRUE, plot=TRUE, fig.height=5.5---------------------
-tsplot(stages, shading="stage", boxes=c("stage","series"),xlim=c(100,81))
+tsplot(stages, shading="stage", boxes=c("stage","series"),xlim=c(100,80))
 
 ranges(fossils, tax="genus", bin="mid", labs=T, 
   labels.args=list(cex=0.6), filt="orig", occs=T, group="ecology")
@@ -123,7 +123,7 @@ colnames(samp)
 ## ----occsAndColls, echo=TRUE, result=FALSE, plot=TRUE, fig.height=5.5----
 par(mar=c(4,4,2,4))
 # basic plot
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="number of occurrences", ylim=c(0,3000))
 lines(stages$mid[1:94], samp$occs)
 # the collections (rescaled, other axis)
@@ -136,7 +136,7 @@ lines(stages$mid[1:94], samp$occs)
 # numerical ages, as bins
 fossils$stgMid <- stages$mid[fossils$stg]
 #plotting
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="number of occurences", ylim=c(0,3000))
 parts(fossils$stgMid, fossils$bath)
 
@@ -145,14 +145,14 @@ cols <- c("#FF0000AA", "#00FF00AA", "#0000FFAA")
 # reorder too
 reord <- c("shal","deep","uk")
 plotnames <-c("shallow", "deep", "unknown")
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="the number of occurrences", ylim=c(0,3000))
 parts(fossils$stgMid, fossils$bath, col=cols, ord=reord, labs=F)
 legend("topleft", inset=c(0.01, 0.01), 
   legend= plotnames, fill=cols, bg="white")
 
 ## ----parts3, echo=TRUE, result=FALSE, plot=TRUE, fig.height=5.5----------
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="proportion of occurrences", ylim=c(0,1))
 parts(fossils$stgMid, fossils$bath, prop=T, col=cols, ord=reord, labs=F)
 legend("bottomleft", inset=c(0.01, 0.1), 
@@ -174,7 +174,7 @@ ddFirst<-divDyn(corals, bin="stg", tax="genus", noNAStart=TRUE)
 # metrics
 ddRec <-divDyn(corals, bin="stg", tax="genus")
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="range-through richness (diversity)", ylim=c(0,250))
 # lines
   lines(stages$mid, ddRec$divRT, col="black", lwd=2)
@@ -183,7 +183,7 @@ ddRec <-divDyn(corals, bin="stg", tax="genus")
 # metrics
 dd <-divDyn(fossils, bin="stg", tax="genus")
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="richness (diversity)", ylim=c(0,250))
 # lines
   lines(stages$mid, ddRec$divRT, col="black", lwd=2)
@@ -195,7 +195,7 @@ dd <-divDyn(fossils, bin="stg", tax="genus")
 # metrics
 dd <-divDyn(fossils, bin="stg", tax="genus")
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="richness (diversity)", ylim=c(0,250))
 # lines
   lines(stages$mid[1:94], dd$divRT, col="red", lwd=2)
@@ -207,14 +207,14 @@ dd <-divDyn(fossils, bin="stg", tax="genus")
 
 ## ----samp3t, echo=TRUE, result=FALSE, plot=TRUE, fig.height=5.5----------
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="three-timer sampling completeness")
   # lines
   lines(stages$mid[1:94], dd$samp3t, col="black", lwd=2)
 
 ## ----ddCorr, echo=TRUE, result=FALSE, plot=TRUE, fig.height=5.5----------
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="three-timer sampling completeness", ylim=c(0,250))
   lines(stages$mid[1:94], dd$divSIB, col="black", lwd=2)
   lines(stages$mid[1:94], dd$divCSIB, col="blue", lwd=2)
@@ -224,13 +224,13 @@ dd <-divDyn(fossils, bin="stg", tax="genus")
 
 ## ----ddExt, echo=TRUE, result=FALSE, plot=TRUE, fig.height=5.5-----------
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="extinction rates", ylim=c(0,2))
   lines(stages$mid[1:94], dd$extPC, col="black", lwd=2)
   lines(stages$mid[1:94], dd$extGF, col="blue", lwd=2)
   lines(stages$mid[1:94], dd$ext2f3, col="green", lwd=2)
   # legend
-  legend("topleft", legend=c("per capita", "gap-filler", "second-for-third"),
+  legend("topright", legend=c("per capita", "gap-filler", "second-for-third"),
     col=c("black", "blue", "green"), lwd=c(2,2,2), bg="white")
 
 ## ----selPrim, echo=TRUE, results=TRUE, plot=TRUE, fig.height=5.5---------
@@ -327,7 +327,7 @@ ddIDbin <- divDyn(fossils, tax="genus", bin="mid_ma")
 
 ## ----ddBasic, echo=TRUE, result=FALSE, plot=TRUE, fig.height=5.5---------
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="Diversity, range-through", ylim=c(0,300))
   lines(-ddIDbin$bin, ddIDbin$divRT, col="black", lwd=2)
   lines(stages$mid[1:94], dd$divRT, col="red", lwd=2)
@@ -350,7 +350,7 @@ legend("topleft", legend=c("unique mid entries",  "stg stages"),
 
 ## ----dd10actual, echo=FALSE, result=FALSE, plot=TRUE, fig.height=5.5-----
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="Diversity, range-through", ylim=c(0,300))
   lines(-ddIDbin$bin, ddIDbin$divRT, col="black", lwd=2)
   lines(stages$mid[1:94], dd$divRT, col="red", lwd=2)
@@ -385,7 +385,7 @@ cor.test(dd$divSIB, sam$occs, method="spearman")
 
 ## ----ddCRBasic, echo=TRUE, results=FALSE, plot=TRUE, fig.height=5.5------
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="SIB diversity", ylim=c(0,200))
 # raw diversity
   lines(stages$mid[1:94], dd$divCSIB, col="black", lwd=2)
@@ -403,7 +403,7 @@ cor.test(dd$divSIB, sam$occs, method="spearman")
 
 ## ----subIter, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5-------
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="genus richness (corrected SIB)", ylim=c(0,200))
   lines(stages$mid[1:94], dd$divCSIB, col="black", lwd=2)
 ## subsampled, stable  
@@ -422,7 +422,7 @@ cor.test(dd$divSIB, sam$occs, method="spearman")
   subCRnd <- subsample(fossils, bin="stg", tax="genus", 
     coll="collection_no", iter=100, q=40, duplicates=FALSE)
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="number of occurrences", ylim=c(0,100))
   lines(stages$mid[1:94], subCR40$divCSIB, col="blue", lwd=2)
   lines(stages$mid[1:94], subCRnd$divCSIB, col="black", lwd=2)
@@ -439,7 +439,7 @@ fossGen <- fossils[!duplicated(collGenus),]
 
 ## ----subFail, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5-------
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="number of occurrences", ylim=c(0,100))
 # subsampled, without failed  
   withoutFail<-subsample(fossGen, bin="stg", tax="genus", 
@@ -455,7 +455,7 @@ fossGen <- fossils[!duplicated(collGenus),]
 
 ## ----subIntact, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5-----
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="per capita extinction rates", ylim=c(0,1))
 ## subsampled, excluding the recent occurrences  
   sub <- subsample(corals, bin="stg", tax="genus", iter=100, 
@@ -472,7 +472,7 @@ fossGen <- fossils[!duplicated(collGenus),]
 
 ## ----subOutput, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5-----
 # basic plot
-  tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+  tsplot(stages, shading="series", boxes="sys", xlim=52:95,
     ylab="richness of genera (corrected SIB)", ylim=c(0,100))
 ## arithmetic mean output
   subArit <- subsample(fossGen, bin="stg", tax="genus", iter=100, q=40, output="arit")
@@ -496,7 +496,7 @@ names(subDist)
 dim(subDist$divCSIB)
 
 ## ----subMultiRes, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5----
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="subsampled richness of genera (corrected SIB)", ylim=c(0,150))
 
 plottedVar <- subDist$divCSIB
@@ -508,12 +508,12 @@ csibMeans<- apply(plottedVar,1, mean, na.rm=T)
 lines(stages$mid[1:94], csibMeans , col="red", lwd=2)
 
 ## ----shades, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5--------
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="subsampled richness of genera (corrected SIB)", ylim=c(0,150))
 shades(stages$mid[1:94], plottedVar, res=10, col="black")
 
 ## ----shades100, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5-----
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="subsampled richness of genera (corrected SIB)", ylim=c(0,150))
 shades(stages$mid[1:94], plottedVar, col="blue", res=c(0.05,0.25,0.75,0.95))
 
@@ -567,7 +567,7 @@ cor.test(maxPaLat, stages$mid[54:94], method="spearman")
 ## ----subPLSmm, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5------
 subMaxPaLat <- subsample(fossGen, bin="stg", tax="genus", 
   iter=100, q=20,FUN=PL)
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="maximum sampled paleolatitude", ylim=c(0,90))
 lines(stages$mid[54:94], maxPaLat, col="blue")
 lines(stages$mid[54:94], subMaxPaLat, col="black")
@@ -588,7 +588,7 @@ subOW <- subsample(fossGen, bin="stg", tax="genus", coll="collection_no",
 
 ## ----subOW, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5---------
 subCR <- subsample(fossGen, bin="stg", tax="genus", iter=100, q=40)
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="corrected SIB diversity", ylim=c(0,90))
 lines(stages$mid[1:94], subCR$divCSIB, col="black")
 lines(stages$mid[1:94], subOW$divCSIB, col="blue")
@@ -614,7 +614,7 @@ subST[54:94, "occs"]
 ## ----subO2, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5---------
 subO2W <- subsample(fossGen, bin="stg", tax="genus", coll="collection_no", 
   iter=100, q=80, type="oxw", x=2)
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="corrected SIB genus richness", ylim=c(0,90))
 lines(stages$mid[1:94], subCR$divCSIB, col="black")
 lines(stages$mid[1:94], subOW$divCSIB, col="blue")
@@ -635,7 +635,7 @@ for(i in quotas){
 }
 
 ## ----subCRmanyShow, echo=TRUE, results =FALSE, plot=TRUE, fig.height=5.5----
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="corrected SIB richness", ylim=c(0,90))
 for(i in quotas){
   current <- get(paste("cr", i, sep=""))
@@ -651,7 +651,7 @@ sqs0.3 <-subsample(fossGen, iter=50, q=0.3,
   tax="genus", bin="stg", type="sqs")
 
 # plotting
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="corrected SIB richness", ylim=c(0,175))
 lines(stages$mid[1:94], sqs0.6$divCSIB, col="blue")
 lines(stages$mid[1:94], sqs0.3$divCSIB, col="green")
@@ -670,7 +670,7 @@ sqsNoSing <-subsample(fossGen, iter=50, q=0.4,
   tax="genus", bin="stg", type="sqs", singleton=FALSE)
 
 # plotting
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="corrected SIB richness", ylim=c(0,100))
 lines(stages$mid[1:94], sqsRefSing$divCSIB, col="blue")
 lines(stages$mid[1:94], sqsCollSing$divCSIB, col="black")
@@ -686,7 +686,7 @@ sqsCorr <-subsample(fossGen, iter=50, q=0.5,
  type="sqs", singleton="ref", excludeDominant=T, largestColl=T)
 
 # plotting
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="corrected SIB richness", ylim=c(0,100))
 lines(stages$mid[1:94], sqsPure$divCSIB, col="blue")
 lines(stages$mid[1:94], sqsCorr$divCSIB, col="black")
@@ -700,7 +700,7 @@ sqsByColl <-subsample(fossGen, iter=50, q=0.5,
  type="sqs", singleton="ref", excludeDominant=T, largestColl=T, byList=TRUE)
 
 # plotting
-tsplot(stages, shading="series", boxes="sys", xlim=51:95,
+tsplot(stages, shading="series", boxes="sys", xlim=52:95,
   ylab="corrected SIB richness", ylim=c(0,100))
 lines(stages$mid[1:94], sqsByColl$divCSIB, col="blue")
 lines(stages$mid[1:94], sqsCorr$divCSIB, col="black")
@@ -713,7 +713,7 @@ knownBath <- fossils[fossils$bath!="uk",]
 
 ## ----affMajor, echo=TRUE, results =TRUE----------------------------------
 affMajor <- affinity(knownBath, bin="stg", tax="genus", 
-  method="majority", env="bath")
+  method="majority", coll="collection_no", env="bath")
 table(affMajor)
 
 ## ----tabBath, echo=TRUE, results =TRUE-----------------------------------
@@ -721,16 +721,16 @@ table(knownBath$bath)
 
 ## ----affBin, echo=TRUE, results =TRUE, plot=TRUE, dev='png', dpi=300-----
 affBin1 <- affinity(knownBath, bin="stg", tax="genus", 
-  method="binom", env="bath")
+  method="binom", coll="collection_no", env="bath")
 table(affBin1)
 
 ## ----affBin2, echo=TRUE, results =TRUE-----------------------------------
 affBin0.5 <- affinity(knownBath, bin="stg", tax="genus", 
-  method="binom", env="bath", alpha=0.5)
+  method="binom", coll="collection_no", env="bath", alpha=0.5)
 table(affBin0.5)
 
 affBin0.1 <- affinity(knownBath, bin="stg", tax="genus", 
-  method="binom", env="bath", alpha=0.1)
+  method="binom", coll="collection_no", env="bath", alpha=0.1)
 table(affBin0.1)
 
 ## ----georan1, echo=TRUE, results =TRUE-----------------------------------
